==> renku-1.2.1-py3-none-any.whl: renku/core/dataset/providers/__init__.py <==
# -*- coding: utf-8 -*-
#
# Copyright 2020 - Swiss Data Science Center (SDSC)
# A partnership between École Polytechnique Fédérale de Lausanne (EPFL) and
# Eidgenössische Technische Hochschule Zürich (ETHZ).
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Third party data registry integration."""
from urllib.parse import urlparse

from renku.core.util.doi import is_doi


class ProviderFactory:
    """Create a provider type from URI."""

    @staticmethod
    def providers():
        """Returns all supported providers."""
        from renku.core.dataset.providers.dataverse import DataverseProvider
        from renku.core.dataset.providers.olos import OLOSProvider
        from renku.core.dataset.providers.renku import RenkuProvider
        from renku.core.dataset.providers.zenodo import ZenodoProvider

        return {"OLOS": OLOSProvider, "Renku": RenkuProvider, "Zenodo": ZenodoProvider, "Dataverse": DataverseProvider}

    @staticmethod
    def from_uri(uri):
        """Get provider type based on uri."""
        is_doi_ = is_doi(uri)
        if is_doi_ is None:
            url = urlparse(uri)
            if bool(url.scheme and url.netloc and url.params == "") is False:
                return None, "Cannot parse URL."

        provider = None
        warning = ""

        for _, potential_provider in ProviderFactory.providers().items():
            try:
                if potential_provider.supports(uri):
                    provider = potential_provider
                    break
            except (Exception, BaseException) as e:
                warning += "Couldn't test provider {prov}: {err}\n".format(prov=potential_provider, err=e)

        supported_providers = ", ".join(ProviderFactory.providers().keys())

        if is_doi_ and provider is None:
            return (
                None,
                (
                    warning
                    + "Reason: provider {} not found".format(uri.split("/")[1].split(".")[0])  # Get DOI provider name.
                    + "\nHint: Supported providers are: {}".format(supported_providers)
                ),
            )
        elif provider is None:
            return (
                None,
                (
                    warning
                    + "Reason: provider not found for {} ".format(uri)
                    + "\nHint: Supported providers are: {}".format(supported_providers)
                ),
            )
        else:
            return provider(is_doi=is_doi_), warning

    @staticmethod
    def from_id(provider_id):
        """Get provider type based on identifier."""
        provider = next((p for n, p in ProviderFactory.providers().items() if n.lower() == provider_id.lower()), None)

        if not provider:
            raise KeyError(f"Provider {provider_id} not found.")

        return provider()

==> renku-1.2.3-py3-none-any.whl: renku/core/dataset/providers/__init__.py <==
# -*- coding: utf-8 -*-
#
# Copyright 2020 - Swiss Data Science Center (SDSC)
# A partnership between École Polytechnique Fédérale de Lausanne (EPFL) and
# Eidgenössische Technische Hochschule Zürich (ETHZ).
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Third party data registry integration."""

from typing import TYPE_CHECKING, Optional, Tuple
from urllib.parse import urlparse

from renku.core.util.doi import is_doi

if TYPE_CHECKING:
    from renku.core.dataset.providers.api import ProviderApi


class ProviderFactory:
    """Create a provider type from URI."""

    @staticmethod
    def providers():
        """Returns all supported providers."""
        from renku.core.dataset.providers.dataverse import DataverseProvider
        from renku.core.dataset.providers.olos import OLOSProvider
        from renku.core.dataset.providers.renku import RenkuProvider
        from renku.core.dataset.providers.zenodo import ZenodoProvider

        return {"OLOS": OLOSProvider, "Renku": RenkuProvider, "Zenodo": ZenodoProvider, "Dataverse": DataverseProvider}

    @staticmethod
    def from_uri(uri) -> Tuple[Optional["ProviderApi"], str]:
        """Get provider type based on uri."""
        is_doi_ = is_doi(uri)
        if is_doi_ is None:
            url = urlparse(uri)
            if bool(url.scheme and url.netloc and url.params == "") is False:
                return None, "Cannot parse URL."

        provider = None
        warning = ""

        for _, potential_provider in ProviderFactory.providers().items():
            try:
                if potential_provider.supports(uri):
                    provider = potential_provider
                    break
            except (Exception, BaseException) as e:
                warning += "Couldn't test provider {prov}: {err}\n".format(prov=potential_provider, err=e)

        supported_providers = ", ".join(ProviderFactory.providers().keys())

        if is_doi_ and provider is None:
            return (
                None,
                (
                    warning
                    + "Reason: provider {} not found".format(uri.split("/")[1].split(".")[0])  # Get DOI provider name.
                    + "\nHint: Supported providers are: {}".format(supported_providers)
                ),
            )
        elif provider is None:
            return (
                None,
                (
                    warning
                    + "Reason: provider not found for {} ".format(uri)
                    + "\nHint: Supported providers are: {}".format(supported_providers)
                ),
            )
        else:
            return provider(is_doi=is_doi_), warning

    @staticmethod
    def from_id(provider_id) -> "ProviderApi":
        """Get provider type based on identifier."""
        provider = next((p for n, p in ProviderFactory.providers().items() if n.lower() == provider_id.lower()), None)

        if not provider:
            raise KeyError(f"Provider {provider_id} not found.")

        return provider()
